@@ -16,7 +16,7 @@ pub type LLVMOrcExecutorAddress = u64;
 
 /// Generic linkage flags for a symbol definition.
 #[repr(C)]
-#[derive(Debug)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LLVMJITSymbolGenericFlags {
     LLVMJITSymbolGenericFlagsExported = 1,
     LLVMJITSymbolGenericFlagsWeak = 2,
@@ -31,16 +31,16 @@ pub type LLVMJITSymbolTargetFlags = u8;
 #[repr(C)]
 #[derive(Debug)]
 pub struct LLVMJITSymbolFlags {
-    GenericFlags: u8,
-    TargetFlags: u8,
+    pub GenericFlags: u8,
+    pub TargetFlags: u8,
 }
 
 /// An evaluated symbol address and flags.
 #[repr(C)]
 #[derive(Debug)]
 pub struct LLVMJITEvaluatedSymbol {
-    Address: LLVMOrcExecutorAddress,
-    Flags: LLVMJITSymbolFlags,
+    pub Address: LLVMOrcExecutorAddress,
+    pub Flags: LLVMJITSymbolFlags,
 }
 
 #[derive(Debug)]
@@ -63,8 +63,8 @@ pub type LLVMOrcSymbolStringPoolEntryRef = *mut LLVMOrcOpaqueSymbolStringPoolEnt
 #[repr(C)]
 #[derive(Debug)]
 pub struct LLVMOrcCSymbolFlagsMapPair {
-    Name: LLVMOrcSymbolStringPoolEntryRef,
-    Flags: LLVMJITSymbolFlags,
+    pub Name: LLVMOrcSymbolStringPoolEntryRef,
+    pub Flags: LLVMJITSymbolFlags,
 }
 
 pub type LLVMOrcCSymbolFlagsMapPairs = *mut LLVMOrcCSymbolFlagsMapPair;
@@ -73,8 +73,8 @@ pub type LLVMOrcCSymbolFlagsMapPairs = *mut LLVMOrcCSymbolFlagsMapPair;
 #[repr(C)]
 #[derive(Debug)]
 pub struct LLVMJITCSymbolMapPair {
-    Name: LLVMOrcSymbolStringPoolEntryRef,
-    Sym: LLVMJITEvaluatedSymbol,
+    pub Name: LLVMOrcSymbolStringPoolEntryRef,
+    pub Sym: LLVMJITEvaluatedSymbol,
 }
 
 /// A list of (SymbolStringPtr, JITEvaluatedSymbol) pairs that can be
@@ -84,15 +84,15 @@ pub type LLVMOrcCSymbolMapPairs = *mut LLVMJITCSymbolMapPair;
 #[repr(C)]
 #[derive(Debug)]
 pub struct LLVMOrcCSymbolAliasMapEntry {
-    Name: LLVMOrcSymbolStringPoolEntryRef,
-    Flags: LLVMJITSymbolFlags,
+    pub Name: LLVMOrcSymbolStringPoolEntryRef,
+    pub Flags: LLVMJITSymbolFlags,
 }
 
 #[repr(C)]
 #[derive(Debug)]
 pub struct LLVMOrcCSymbolAliasMapPair {
-    Name: LLVMOrcSymbolStringPoolEntryRef,
-    Entry: LLVMOrcCSymbolAliasMapEntry,
+    pub Name: LLVMOrcSymbolStringPoolEntryRef,
+    pub Entry: LLVMOrcCSymbolAliasMapEntry,
 }
 
 pub type LLVMOrcCSymbolAliasMapPairs = *mut LLVMOrcCSymbolAliasMapPair;
@@ -104,15 +104,15 @@ pub type LLVMOrcJITDylibRef = *mut LLVMOrcOpaqueJITDylib;
 #[repr(C)]
 #[derive(Debug)]
 pub struct LLVMOrcCSymbolsList {
-    Symbols: *mut LLVMOrcSymbolStringPoolEntryRef,
-    Length: ::libc::size_t,
+    pub Symbols: *mut LLVMOrcSymbolStringPoolEntryRef,
+    pub Length: ::libc::size_t,
 }
 
 #[repr(C)]
 #[derive(Debug)]
 pub struct LLVMOrcCDependenceMapPair {
-    JD: LLVMOrcJITDylibRef,
-    Names: LLVMOrcCSymbolsList,
+    pub JD: LLVMOrcJITDylibRef,
+    pub Names: LLVMOrcCSymbolsList,
 }
 
 pub type LLVMOrcCDependenceMapPairs = *mut LLVMOrcCDependenceMapPair;
@@ -120,7 +120,7 @@ pub type LLVMOrcCDependenceMapPairs = *mut LLVMOrcCDependenceMapPair;
 /// Lookup kind. This can be used by definition generators when deciding whether
 /// to produce a definition for a requested symbol.
 #[repr(C)]
-#[derive(Debug)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LLVMOrcLookupKind {
     LLVMOrcLookupKindStatic,
     LLVMOrcLookupKindDLSym,
@@ -129,7 +129,7 @@ pub enum LLVMOrcLookupKind {
 /// JITDylib lookup flags. This can be used by definition generators when
 /// deciding whether to produce a definition for a requested symbol.
 #[repr(C)]
-#[derive(Debug)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LLVMOrcJITDylibLookupFlags {
     LLVMOrcJITDylibLookupFlagsMatchExportedSymbolsOnly,
     LLVMOrcJITDylibLookupFlagsMatchAllSymbols,
@@ -137,7 +137,7 @@ pub enum LLVMOrcJITDylibLookupFlags {
 
 /// Symbol lookup flags for lookup sets.
 #[repr(C)]
-#[derive(Debug)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LLVMOrcSymbolLookupFlags {
     LLVMOrcSymbolLookupFlagsRequiredSymbol,
     LLVMOrcSymbolLookupFlagsWeaklyReferencedSymbol,
@@ -147,8 +147,8 @@ pub enum LLVMOrcSymbolLookupFlags {
 #[repr(C)]
 #[derive(Debug)]
 pub struct LLVMOrcCLookupSetElement {
-    Name: LLVMOrcSymbolStringPoolEntryRef,
-    LookupFlags: LLVMOrcSymbolLookupFlags,
+    pub Name: LLVMOrcSymbolStringPoolEntryRef,
+    pub LookupFlags: LLVMOrcSymbolLookupFlags,
 }
 
 /// A set of symbols to look up / generate.
@@ -398,6 +398,19 @@ extern "C" {
         Filter: LLVMOrcSymbolPredicate,
         FilterCtx: *mut ::libc::c_void,
     ) -> LLVMErrorRef;
+    pub fn LLVMOrcCreateDynamicLibrarySearchGeneratorForPath(
+        Result: *mut LLVMOrcDefinitionGeneratorRef,
+        FileName: *const ::libc::c_char,
+        GlobalPrefix: ::libc::c_char,
+        Filter: LLVMOrcSymbolPredicate,
+        FilterCtx: *mut ::libc::c_void,
+    ) -> LLVMErrorRef;
+    pub fn LLVMOrcCreateStaticLibrarySearchGeneratorForPath(
+        Result: *mut LLVMOrcDefinitionGeneratorRef,
+        ObjLayer: LLVMOrcObjectLayerRef,
+        FileName: *const ::libc::c_char,
+        TargetTriple: *const ::libc::c_char,
+    ) -> LLVMErrorRef;
     pub fn LLVMOrcCreateNewThreadSafeContext() -> LLVMOrcThreadSafeContextRef;
     pub fn LLVMOrcThreadSafeContextGetContext(TSCtx: LLVMOrcThreadSafeContextRef)
         -> LLVMContextRef;
